Documentation
¶
Overview ¶
Package jbbsreader provides functionality for reading from a specified JBBS board.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetGlobalRateLimitRPM ¶
SetGlobalRateLimitRPM sets JBBS requests rate per limit, allowing some bursts.
Types ¶
type Board ¶
Board represents a JBBS board whose URL is 'http://jbbs.shitaraba.net/[category]/[id]/'.
func (*Board) FeedNewResponses ¶
FeedNewResponses continuously feeds new responses in all threads of the board to the chan. b.Category and b.ID must be set.
func (*Board) FeedResponsesOnce ¶
FeedResponsesOnce reads all responses in all threads of the board to the chan. b.Category and b.ID must be set.
type Response ¶
type Response struct {
ParentThread *Thread
ID uint // The ID of the response, which is the same as the response number.
Name string // The name of the author.
Email string // The email address of the author.
Date string // The date the response was made. TODO(mogepiyo): Parse the date.
Content string // The content of the response. TODO(mogepiyo): Strip all tags, e.g. <br>.
AuthorID string // The ID of the author.
// contains filtered or unexported fields
}
Response represents each response written to JBBS threads.
type Thread ¶
type Thread struct {
ParentBoard *Board
ID string
Title string // The title of the thread.
NumResponses uint // The number of responses in the thread.
}
Thread represents the thread that can be accessed by the following URL. 'http://jbbs.shitaraba.net/bbs/read.cgi/[board-category]/[board-id]/[thread-id]'